"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const papaparse_1 = require("papaparse");
const fs_1 = require("fs");
const file_1 = require("../utils/file");
class Db {
    constructor() {
        this.storage = {};
    }
    fillCollection(collectionName, csvPath, onCollectionReady, clearBefore) {
        if (clearBefore) {
            this.storage[collectionName] = [];
        }
        const collection = this.getCollection(collectionName);
        fs_1.readFile(csvPath, 'utf-8', (fileErr, data) => {
            if (fileErr) {
                return onCollectionReady();
            }
            papaparse_1.parse(file_1.stripBom(data), {
                header: true,
                quotes: true,
                skipEmptyLines: true,
                complete: result => {
                    let lineNumber = 1;
                    for (const ddfRecord of result.data) {
                        ddfRecord['$$source'] = csvPath;
                        ddfRecord['$$lineNumber'] = lineNumber;
                        collection.push(ddfRecord);
                        lineNumber++;
                    }
                    onCollectionReady(null, result.data);
                },
                error: onCollectionReady
            });
        });
    }
    getCollection(collectionName) {
        if (!this.storage[collectionName]) {
            this.storage[collectionName] = [];
        }
        return this.storage[collectionName];
    }
}
exports.Db = Db;
